@@ -1,4 +1,4 @@
-import paramiko
+import ssh
 from .commands import Command
 from getpass import getpass, getuser
 from os import path
@@ -39,25 +39,24 @@ class Server(object):
 
         self.cwd = '~'
 
-        client = paramiko.SSHClient()
-        client.set_missing_host_key_policy(paramiko.AutoAddPolicy)
+        client = ssh.SSHClient()
+        client.set_missing_host_key_policy(ssh.AutoAddPolicy)
         client.load_system_host_keys()
 
         try:
             client.connect(self.hostname, username=self.username)
-        except paramiko.SSHException:
+        except ssh.SSHException:
             try:
                 client.connect(self.hostname, username=self.username,
                                password=self.password
                                if self.password else getpass(),
                               port=22
                                if not kwargs.get('port') else kwargs.get('22'))
-
-                self.client = client
-
             except:
                 raise Exception("User password is wrong or can not access")
 
+        self.client = client
+
     def commands(self, string, echo=False):
         """
             Use triple quoted strings to send in a mass of shell commands.
@@ -157,7 +156,7 @@ def from_conf(server, config_file=path.expanduser('~/.ssh/config')):
             server.run("whoami")
             >> ["myusername"]
     """
-    ssh_config = paramiko.SSHConfig()
+    ssh_config = ssh.SSHConfig()
 
     with open(config_file) as ssh_conf:
         ssh_config.parse(ssh_conf)
